#define LANG_NAME                        0
#define STRFTIME_DATE_TIME_FORMAT        1
#define STRFTIME_LONG_DATE_FORMAT        2
#define STRFTIME_SHORT_DATE_FORMAT       3
#define STRFTIME_DAYS_SHORT              4
#define STRFTIME_DAYS_LONG               5
#define STRFTIME_MONTHS_SHORT            6
#define STRFTIME_MONTHS_LONG             7
#define STR_DAY                          8
#define STR_DAYS                         9
#define STR_HOUR                         10
#define STR_HOURS                        11
#define STR_MINUTE                       12
#define STR_MINUTES                      13
#define STR_SECOND                       14
#define STR_SECONDS                      15
#define STR_TIMESEP                      16
#define COMMA_SPACE                      17
#define INTERNAL_ERROR                   18
#define SERVICES_IS_BUSY                 19
#define UNKNOWN_COMMAND                  20
#define UNKNOWN_COMMAND_HELP             21
#define SYNTAX_ERROR                     22
#define MORE_INFO                        23
#define NO_HELP_AVAILABLE                24
#define MISSING_QUOTE                    25
#define BAD_EMAIL                        26
#define BAD_URL                          27
#define BAD_USERHOST_MASK                28
#define BAD_NICKUSERHOST_MASK            29
#define BAD_EXPIRY_TIME                  30
#define SENDMAIL_NO_RESOURCES            31
#define READ_ONLY_MODE                   32
#define PASSWORD_INCORRECT               33
#define PASSWORD_WARNING                 34
#define ACCESS_DENIED                    35
#define PERMISSION_DENIED                36
#define MORE_OBSCURE_PASSWORD            37
#define PASSWORD_TRUNCATED               38
#define NICK_NOT_REGISTERED              39
#define NICK_NOT_REGISTERED_HELP         40
#define NICK_TOO_LONG                    41
#define NICK_INVALID                     42
#define NICK_X_NOT_REGISTERED            43
#define NICK_X_ALREADY_REGISTERED        44
#define NICK_X_NOT_IN_USE                45
#define NICK_X_FORBIDDEN                 46
#define NICK_X_SUSPENDED                 47
#define NICK_X_SUSPENDED_MEMOS           48
#define NICK_IDENTIFY_REQUIRED           49
#define NICK_PLEASE_AUTH                 50
#define NICK_X_NOT_ON_CHAN_X             51
#define CHAN_INVALID                     52
#define CHAN_X_NOT_REGISTERED            53
#define CHAN_X_NOT_IN_USE                54
#define CHAN_X_FORBIDDEN                 55
#define CHAN_X_SUSPENDED                 56
#define CHAN_X_SUSPENDED_MEMOS           57
#define CHAN_IDENTIFY_REQUIRED           58
#define SERV_X_NOT_FOUND                 59
#define EXPIRES_NONE                     60
#define EXPIRES_SOON                     61
#define EXPIRES_IN                       62
#define NICK_IS_REGISTERED               63
#define NICK_IS_SECURE                   64
#define NICK_MAY_NOT_BE_USED             65
#define DISCONNECT_IN_1_MINUTE           66
#define DISCONNECT_IN_20_SECONDS         67
#define DISCONNECT_NOW                   68
#define FORCENICKCHANGE_IN_1_MINUTE      69
#define FORCENICKCHANGE_IN_20_SECONDS    70
#define FORCENICKCHANGE_NOW              71
#define NICK_EXPIRES_SOON                72
#define NICK_EXPIRED                     73
#define NICK_REGISTER_SYNTAX             74
#define NICK_REGISTER_REQ_EMAIL_SYNTAX   75
#define NICK_REGISTRATION_DISABLED       76
#define NICK_REGISTRATION_FAILED         77
#define NICK_REG_PLEASE_WAIT             78
#define NICK_REG_PLEASE_WAIT_FIRST       79
#define NICK_CANNOT_BE_REGISTERED        80
#define NICK_REGISTER_EMAIL_UNAUTHED     81
#define NICK_REGISTER_TOO_MANY_NICKS     82
#define NICK_REGISTERED                  83
#define NICK_PASSWORD_IS                 84
#define NICK_IDENTIFY_SYNTAX             85
#define NICK_IDENTIFY_FAILED             86
#define NICK_IDENTIFY_EMAIL_MISSING      87
#define NICK_IDENTIFY_SUCCEEDED          88
#define NICK_DROP_SYNTAX                 89
#define NICK_DROP_WARNING                90
#define NICK_DROP_DISABLED               91
#define NICK_DROP_FAILED                 92
#define NICK_DROPPED                     93
#define NICK_DROPPED_LINKS               94
#define NICK_DROPNICK_SYNTAX             95
#define NICK_X_DROPPED                   96
#define NICK_X_DROPPED_LINKS             97
#define NICK_DROPEMAIL_SYNTAX            98
#define NICK_DROPEMAIL_PATTERN_TOO_LONG  99
#define NICK_DROPEMAIL_NONE              100
#define NICK_DROPEMAIL_COUNT             101
#define NICK_DROPEMAIL_CONFIRM_SYNTAX    102
#define NICK_DROPEMAIL_CONFIRM_UNKNOWN   103
#define NICK_DROPEMAIL_CONFIRM_DROPPING  104
#define NICK_DROPEMAIL_CONFIRM_DROPPED   105
#define NICK_SET_SYNTAX                  106
#define NICK_SET_OPER_SYNTAX             107
#define NICK_SET_DISABLED                108
#define NICK_SET_UNKNOWN_OPTION          109
#define NICK_SET_UNKNOWN_OPTION_OR_BAD_NICK 110
#define NICK_SET_PASSWORD_FAILED         111
#define NICK_SET_PASSWORD_CHANGED        112
#define NICK_SET_PASSWORD_CHANGED_TO     113
#define NICK_SET_LANGUAGE_SYNTAX         114
#define NICK_SET_LANGUAGE_UNKNOWN        115
#define NICK_SET_LANGUAGE_CHANGED        116
#define NICK_SET_URL_CHANGED             117
#define NICK_SET_EMAIL_UNAUTHED          118
#define NICK_SET_EMAIL_TOO_MANY_NICKS    119
#define NICK_SET_EMAIL_CHANGED           120
#define NICK_SET_INFO_CHANGED            121
#define NICK_SET_KILL_SYNTAX             122
#define NICK_SET_KILL_IMMED_SYNTAX       123
#define NICK_SET_KILL_ON                 124
#define NICK_SET_KILL_QUICK              125
#define NICK_SET_KILL_IMMED              126
#define NICK_SET_KILL_IMMED_DISABLED     127
#define NICK_SET_KILL_OFF                128
#define NICK_SET_SECURE_SYNTAX           129
#define NICK_SET_SECURE_ON               130
#define NICK_SET_SECURE_OFF              131
#define NICK_SET_PRIVATE_SYNTAX          132
#define NICK_SET_PRIVATE_ON              133
#define NICK_SET_PRIVATE_OFF             134
#define NICK_SET_HIDE_SYNTAX             135
#define NICK_SET_HIDE_EMAIL_ON           136
#define NICK_SET_HIDE_EMAIL_OFF          137
#define NICK_SET_HIDE_MASK_ON            138
#define NICK_SET_HIDE_MASK_OFF           139
#define NICK_SET_HIDE_QUIT_ON            140
#define NICK_SET_HIDE_QUIT_OFF           141
#define NICK_SET_TIMEZONE_SYNTAX         142
#define NICK_SET_TIMEZONE_TO             143
#define NICK_SET_TIMEZONE_DEFAULT        144
#define NICK_SET_MAINNICK_NOT_FOUND      145
#define NICK_SET_MAINNICK_CHANGED        146
#define NICK_SET_NOEXPIRE_SYNTAX         147
#define NICK_SET_NOEXPIRE_ON             148
#define NICK_SET_NOEXPIRE_OFF            149
#define NICK_UNSET_SYNTAX                150
#define NICK_UNSET_SYNTAX_REQ_EMAIL      151
#define NICK_UNSET_URL                   152
#define NICK_UNSET_EMAIL                 153
#define NICK_UNSET_INFO                  154
#define NICK_UNSET_EMAIL_BAD             155
#define NICK_UNSET_EMAIL_OTHER_BAD       156
#define NICK_ACCESS_SYNTAX               157
#define NICK_ACCESS_DISABLED             158
#define NICK_ACCESS_ALREADY_PRESENT      159
#define NICK_ACCESS_REACHED_LIMIT        160
#define NICK_ACCESS_NO_NICKS             161
#define NICK_ACCESS_ADDED                162
#define NICK_ACCESS_NOT_FOUND            163
#define NICK_ACCESS_DELETED              164
#define NICK_ACCESS_LIST_EMPTY           165
#define NICK_ACCESS_LIST                 166
#define NICK_ACCESS_LIST_X_EMPTY         167
#define NICK_ACCESS_LIST_X               168
#define NICK_OLD_LINK_SYNTAX             169
#define NICK_LINK_SYNTAX                 170
#define NICK_LINK_DISABLED               171
#define NICK_LINK_FAILED                 172
#define NICK_CANNOT_BE_LINKED            173
#define NICK_OLD_LINK_SAME               174
#define NICK_LINK_SAME                   175
#define NICK_LINK_ALREADY_LINKED         176
#define NICK_LINK_IN_USE                 177
#define NICK_LINK_TOO_MANY               178
#define NICK_LINK_TOO_MANY_NICKS         179
#define NICK_OLD_LINK_TOO_MANY_CHANNELS  180
#define NICK_OLD_LINKED                  181
#define NICK_LINKED                      182
#define NICK_OLD_UNLINK_SYNTAX           183
#define NICK_UNLINK_SYNTAX               184
#define NICK_UNLINK_OPER_SYNTAX          185
#define NICK_UNLINK_DISABLED             186
#define NICK_UNLINK_FAILED               187
#define NICK_UNLINK_SAME                 188
#define NICK_OLD_UNLINK_NOT_LINKED       189
#define NICK_UNLINK_NOT_LINKED_YOURS     190
#define NICK_UNLINK_NOT_LINKED           191
#define NICK_OLD_UNLINKED                192
#define NICK_UNLINKED                    193
#define NICK_X_UNLINKED                  194
#define NICK_OLD_LISTLINKS_SYNTAX        195
#define NICK_LISTLINKS_SYNTAX            196
#define NICK_LISTLINKS_HEADER            197
#define NICK_LISTLINKS_FOOTER            198
#define NICK_INFO_SYNTAX                 199
#define NICK_INFO_REALNAME               200
#define NICK_INFO_ADDRESS                201
#define NICK_INFO_ADDRESS_ONLINE         202
#define NICK_INFO_ADDRESS_ONLINE_NOHOST  203
#define NICK_INFO_TIME_REGGED            204
#define NICK_INFO_LAST_SEEN              205
#define NICK_INFO_LAST_QUIT              206
#define NICK_INFO_URL                    207
#define NICK_INFO_EMAIL                  208
#define NICK_INFO_EMAIL_UNAUTHED         209
#define NICK_INFO_INFO                   210
#define NICK_INFO_OPTIONS                211
#define NICK_INFO_OPT_KILL               212
#define NICK_INFO_OPT_SECURE             213
#define NICK_INFO_OPT_PRIVATE            214
#define NICK_INFO_OPT_NONE               215
#define NICK_INFO_NO_EXPIRE              216
#define NICK_INFO_SUSPEND_DETAILS        217
#define NICK_INFO_SUSPEND_REASON         218
#define NICK_INFO_SHOW_ALL               219
#define NICK_LISTCHANS_SYNTAX            220
#define NICK_LISTCHANS_NONE              221
#define NICK_LISTCHANS_HEADER            222
#define NICK_LISTCHANS_END               223
#define NICK_LIST_SYNTAX                 224
#define NICK_LIST_OPER_SYNTAX            225
#define NICK_LIST_OPER_SYNTAX_AUTH       226
#define NICK_LIST_HEADER                 227
#define NICK_LIST_RESULTS                228
#define NICK_LISTEMAIL_NONE              229
#define NICK_RECOVER_SYNTAX              230
#define NICK_NO_RECOVER_SELF             231
#define NICK_RECOVERED                   232
#define NICK_RELEASE_SYNTAX              233
#define NICK_RELEASE_NOT_HELD            234
#define NICK_RELEASED                    235
#define NICK_GHOST_SYNTAX                236
#define NICK_NO_GHOST_SELF               237
#define NICK_GHOST_KILLED                238
#define NICK_GETPASS_SYNTAX              239
#define NICK_GETPASS_UNAVAILABLE         240
#define NICK_GETPASS_PASSWORD_IS         241
#define NICK_FORBID_SYNTAX               242
#define NICK_FORBID_SUCCEEDED            243
#define NICK_FORBID_FAILED               244
#define NICK_SUSPEND_SYNTAX              245
#define NICK_SUSPEND_SUCCEEDED           246
#define NICK_SUSPEND_ALREADY_SUSPENDED   247
#define NICK_UNSUSPEND_SYNTAX            248
#define NICK_UNSUSPEND_SUCCEEDED         249
#define NICK_UNSUSPEND_NOT_SUSPENDED     250
#define NICK_AJOIN_SYNTAX                251
#define NICK_AJOIN_ADD_SYNTAX            252
#define NICK_AJOIN_DEL_SYNTAX            253
#define NICK_AJOIN_DISABLED              254
#define NICK_AJOIN_ALREADY_PRESENT       255
#define NICK_AJOIN_LIST_FULL             256
#define NICK_AJOIN_ADDED                 257
#define NICK_AJOIN_NOT_FOUND             258
#define NICK_AJOIN_DELETED               259
#define NICK_AJOIN_LIST_EMPTY            260
#define NICK_AJOIN_LIST                  261
#define NICK_AJOIN_LIST_X_EMPTY          262
#define NICK_AJOIN_LIST_X                263
#define NICK_AUTH_SENT                   264
#define NICK_AUTH_FOR_REGISTER           265
#define NICK_AUTH_FOR_SET_EMAIL          266
#define NICK_AUTH_NOT_NEEDED             267
#define NICK_AUTH_NO_AUTHCODE            268
#define NICK_AUTH_HAS_AUTHCODE           269
#define PASSWORD_WARNING_FOR_AUTH        270
#define NICK_AUTH_MAIL_SUBJECT           271
#define NICK_AUTH_MAIL_BODY              272
#define NICK_AUTH_MAIL_TEXT_REG          273
#define NICK_AUTH_MAIL_TEXT_EMAIL        274
#define NICK_AUTH_MAIL_TEXT_SENDAUTH     275
#define NICK_AUTH_MAIL_BODY_SETAUTH      276
#define NICK_AUTH_SYNTAX                 277
#define NICK_AUTH_DISABLED               278
#define NICK_AUTH_FAILED                 279
#define NICK_AUTH_SUCCEEDED_REGISTER     280
#define NICK_AUTH_SUCCEEDED_SET_EMAIL    281
#define NICK_AUTH_SUCCEEDED_SETAUTH      282
#define NICK_SENDAUTH_SYNTAX             283
#define NICK_SENDAUTH_TOO_SOON           284
#define NICK_SENDAUTH_FAILED             285
#define NICK_SETAUTH_SYNTAX              286
#define NICK_SETAUTH_NO_EMAIL            287
#define NICK_SETAUTH_AUTHCODE_SET        288
#define NICK_SETAUTH_SEND_FAILED         289
#define NICK_SETAUTH_SEND_TEMPFAIL       290
#define NICK_SETAUTH_USER_NOTICE         291
#define NICK_GETAUTH_SYNTAX              292
#define NICK_GETAUTH_AUTHCODE_IS         293
#define NICK_CLEARAUTH_SYNTAX            294
#define NICK_CLEARAUTH_CLEARED           295
#define NICK_SENDPASS_MAIL_SUBJECT       296
#define NICK_SENDPASS_MAIL_BODY          297
#define NICK_SENDPASS_SYNTAX             298
#define NICK_SENDPASS_FAILED             299
#define NICK_SENDPASS_NO_EMAIL           300
#define NICK_SENDPASS_NOT_AUTHED         301
#define NICK_SENDPASS_TOO_SOON           302
#define NICK_SENDPASS_SENT               303
#define CHAN_LEVEL_AUTOOP                304
#define CHAN_LEVEL_AUTOVOICE             305
#define CHAN_LEVEL_INVITE                306
#define CHAN_LEVEL_AKICK                 307
#define CHAN_LEVEL_SET                   308
#define CHAN_LEVEL_CLEAR                 309
#define CHAN_LEVEL_UNBAN                 310
#define CHAN_LEVEL_OPDEOP                311
#define CHAN_LEVEL_ACCESS_LIST           312
#define CHAN_LEVEL_ACCESS_CHANGE         313
#define CHAN_LEVEL_MEMO                  314
#define CHAN_LEVEL_VOICE                 315
#define CHAN_LEVEL_AUTOHALFOP            316
#define CHAN_LEVEL_HALFOP                317
#define CHAN_LEVEL_AUTOPROTECT           318
#define CHAN_LEVEL_PROTECT               319
#define CHAN_LEVEL_KICK                  320
#define CHAN_LEVEL_STATUS                321
#define CHAN_LEVEL_TOPIC                 322
#define CHAN_IS_REGISTERED               323
#define CHAN_MAY_NOT_BE_USED             324
#define CHAN_NOT_ALLOWED_TO_JOIN         325
#define CHAN_MUST_IDENTIFY_NICK          326
#define CHAN_BOUNCY_MODES                327
#define CHAN_REGISTER_SYNTAX             328
#define CHAN_REGISTER_DISABLED           329
#define CHAN_REGISTER_SHORT_CHANNEL      330
#define CHAN_REGISTER_NOT_LOCAL          331
#define CHAN_REGISTER_INVALID_NAME       332
#define CHAN_MUST_REGISTER_NICK          333
#define CHAN_MAY_NOT_BE_REGISTERED       334
#define CHAN_ALREADY_REGISTERED          335
#define CHAN_MUST_BE_CHANOP              336
#define CHAN_REACHED_CHANNEL_LIMIT       337
#define CHAN_EXCEEDED_CHANNEL_LIMIT      338
#define CHAN_REGISTRATION_FAILED         339
#define CHAN_REGISTERED                  340
#define CHAN_PASSWORD_IS                 341
#define CHAN_IDENTIFY_SYNTAX             342
#define CHAN_IDENTIFY_FAILED             343
#define CHAN_IDENTIFY_SUCCEEDED          344
#define CHAN_DROP_SYNTAX                 345
#define CHAN_DROP_DISABLED               346
#define CHAN_DROPPED                     347
#define CHAN_SET_SYNTAX                  348
#define CHAN_SET_DISABLED                349
#define CHAN_SET_UNKNOWN_OPTION          350
#define CHAN_SET_FOUNDER_TOO_MANY_CHANS  351
#define CHAN_FOUNDER_CHANGED             352
#define CHAN_SUCCESSOR_CHANGED           353
#define CHAN_SUCCESSOR_IS_FOUNDER        354
#define CHAN_SET_PASSWORD_FAILED         355
#define CHAN_PASSWORD_CHANGED            356
#define CHAN_PASSWORD_CHANGED_TO         357
#define CHAN_DESC_CHANGED                358
#define CHAN_URL_CHANGED                 359
#define CHAN_EMAIL_CHANGED               360
#define CHAN_ENTRY_MSG_CHANGED           361
#define CHAN_SET_MLOCK_NEED_PLUS_MINUS   362
#define CHAN_SET_MLOCK_NEED_PARAM        363
#define CHAN_SET_MLOCK_NEED_POSITIVE     364
#define CHAN_SET_MLOCK_MODE_REG_BAD      365
#define CHAN_SET_MLOCK_LINK_BAD          366
#define CHAN_SET_MLOCK_LINK_SAME         367
#define CHAN_SET_MLOCK_REQUIRES          368
#define CHAN_SET_MLOCK_BAD_PARAM         369
#define CHAN_SET_MLOCK_UNKNOWN_CHAR      370
#define CHAN_SET_MLOCK_CANNOT_LOCK       371
#define CHAN_MLOCK_CHANGED               372
#define CHAN_MLOCK_REMOVED               373
#define CHAN_SET_HIDE_SYNTAX             374
#define CHAN_SET_HIDE_EMAIL_ON           375
#define CHAN_SET_HIDE_EMAIL_OFF          376
#define CHAN_SET_HIDE_TOPIC_ON           377
#define CHAN_SET_HIDE_TOPIC_OFF          378
#define CHAN_SET_HIDE_MLOCK_ON           379
#define CHAN_SET_HIDE_MLOCK_OFF          380
#define CHAN_SET_KEEPTOPIC_SYNTAX        381
#define CHAN_SET_KEEPTOPIC_ON            382
#define CHAN_SET_KEEPTOPIC_OFF           383
#define CHAN_SET_TOPICLOCK_SYNTAX        384
#define CHAN_SET_TOPICLOCK_ON            385
#define CHAN_SET_TOPICLOCK_OFF           386
#define CHAN_SET_PRIVATE_SYNTAX          387
#define CHAN_SET_PRIVATE_ON              388
#define CHAN_SET_PRIVATE_OFF             389
#define CHAN_SET_SECUREOPS_SYNTAX        390
#define CHAN_SET_SECUREOPS_ON            391
#define CHAN_SET_SECUREOPS_OFF           392
#define CHAN_SET_LEAVEOPS_SYNTAX         393
#define CHAN_SET_LEAVEOPS_ON             394
#define CHAN_SET_LEAVEOPS_OFF            395
#define CHAN_SET_RESTRICTED_SYNTAX       396
#define CHAN_SET_RESTRICTED_ON           397
#define CHAN_SET_RESTRICTED_OFF          398
#define CHAN_SET_SECURE_SYNTAX           399
#define CHAN_SET_SECURE_ON               400
#define CHAN_SET_SECURE_OFF              401
#define CHAN_SET_OPNOTICE_SYNTAX         402
#define CHAN_SET_OPNOTICE_ON             403
#define CHAN_SET_OPNOTICE_OFF            404
#define CHAN_SET_ENFORCE_SYNTAX          405
#define CHAN_SET_ENFORCE_ON              406
#define CHAN_SET_ENFORCE_OFF             407
#define CHAN_SET_NOEXPIRE_SYNTAX         408
#define CHAN_SET_NOEXPIRE_ON             409
#define CHAN_SET_NOEXPIRE_OFF            410
#define CHAN_UNSET_SYNTAX                411
#define CHAN_SUCCESSOR_UNSET             412
#define CHAN_URL_UNSET                   413
#define CHAN_EMAIL_UNSET                 414
#define CHAN_ENTRY_MSG_UNSET             415
#define CHAN_ACCESS_SYNTAX               416
#define CHAN_ACCESS_DISABLED             417
#define CHAN_ACCESS_LEVEL_NONZERO        418
#define CHAN_ACCESS_LEVEL_RANGE          419
#define CHAN_ACCESS_NICKS_ONLY           420
#define CHAN_ACCESS_REACHED_LIMIT        421
#define CHAN_ACCESS_LEVEL_UNCHANGED      422
#define CHAN_ACCESS_LEVEL_CHANGED        423
#define CHAN_ACCESS_ADDED                424
#define CHAN_ACCESS_NO_SUCH_ENTRY        425
#define CHAN_ACCESS_NOT_FOUND            426
#define CHAN_ACCESS_NO_MATCH             427
#define CHAN_ACCESS_DELETED              428
#define CHAN_ACCESS_DELETED_ONE          429
#define CHAN_ACCESS_DELETED_SEVERAL      430
#define CHAN_ACCESS_LIST_EMPTY           431
#define CHAN_ACCESS_LIST_HEADER          432
#define CHAN_ACCESS_LIST_FORMAT          433
#define CHAN_ACCESS_COUNT                434
#define CHAN_SOP_SYNTAX                  435
#define CHAN_AOP_SYNTAX                  436
#define CHAN_HOP_SYNTAX                  437
#define CHAN_VOP_SYNTAX                  438
#define CHAN_XOP_ADDED                   439
#define CHAN_XOP_LEVEL_CHANGED           440
#define CHAN_XOP_LEVEL_UNCHANGED         441
#define CHAN_XOP_NICKS_ONLY              442
#define CHAN_XOP_NICKS_ONLY_HOP          443
#define CHAN_XOP_REACHED_LIMIT           444
#define CHAN_XOP_REACHED_LIMIT_HOP       445
#define CHAN_XOP_NOT_FOUND               446
#define CHAN_XOP_NO_SUCH_ENTRY           447
#define CHAN_XOP_NO_MATCH                448
#define CHAN_XOP_DELETED                 449
#define CHAN_XOP_DELETED_ONE             450
#define CHAN_XOP_DELETED_SEVERAL         451
#define CHAN_XOP_LIST_EMPTY              452
#define CHAN_XOP_LIST_HEADER             453
#define CHAN_XOP_LIST_FORMAT             454
#define CHAN_XOP_COUNT                   455
#define CHAN_AKICK_SYNTAX                456
#define CHAN_AKICK_DISABLED              457
#define CHAN_AKICK_ALREADY_EXISTS        458
#define CHAN_AKICK_REACHED_LIMIT         459
#define CHAN_AKICK_ADDED                 460
#define CHAN_AKICK_NO_SUCH_ENTRY         461
#define CHAN_AKICK_NOT_FOUND             462
#define CHAN_AKICK_NO_MATCH              463
#define CHAN_AKICK_DELETED               464
#define CHAN_AKICK_DELETED_ONE           465
#define CHAN_AKICK_DELETED_SEVERAL       466
#define CHAN_AKICK_LIST_EMPTY            467
#define CHAN_AKICK_LIST_HEADER           468
#define CHAN_AKICK_VIEW_FORMAT           469
#define CHAN_AKICK_VIEW_UNUSED_FORMAT    470
#define CHAN_AKICK_ENFORCE_DONE          471
#define CHAN_AKICK_COUNT                 472
#define CHAN_LEVELS_SYNTAX               473
#define CHAN_LEVELS_READONLY             474
#define CHAN_LEVELS_RANGE                475
#define CHAN_LEVELS_CHANGED              476
#define CHAN_LEVELS_UNKNOWN              477
#define CHAN_LEVELS_DISABLED             478
#define CHAN_LEVELS_LIST_HEADER          479
#define CHAN_LEVELS_LIST_DISABLED        480
#define CHAN_LEVELS_LIST_FOUNDER         481
#define CHAN_LEVELS_LIST_NORMAL          482
#define CHAN_LEVELS_RESET                483
#define CHAN_INFO_SYNTAX                 484
#define CHAN_INFO_HEADER                 485
#define CHAN_INFO_FOUNDER                486
#define CHAN_INFO_SUCCESSOR              487
#define CHAN_INFO_DESCRIPTION            488
#define CHAN_INFO_ENTRYMSG               489
#define CHAN_INFO_TIME_REGGED            490
#define CHAN_INFO_LAST_USED              491
#define CHAN_INFO_LAST_TOPIC             492
#define CHAN_INFO_TOPIC_SET_BY           493
#define CHAN_INFO_URL                    494
#define CHAN_INFO_EMAIL                  495
#define CHAN_INFO_OPTIONS                496
#define CHAN_INFO_OPT_PRIVATE            497
#define CHAN_INFO_OPT_KEEPTOPIC          498
#define CHAN_INFO_OPT_TOPICLOCK          499
#define CHAN_INFO_OPT_SECUREOPS          500
#define CHAN_INFO_OPT_LEAVEOPS           501
#define CHAN_INFO_OPT_RESTRICTED         502
#define CHAN_INFO_OPT_SECURE             503
#define CHAN_INFO_OPT_OPNOTICE           504
#define CHAN_INFO_OPT_ENFORCE            505
#define CHAN_INFO_OPT_NONE               506
#define CHAN_INFO_MODE_LOCK              507
#define CHAN_INFO_NO_EXPIRE              508
#define CHAN_INFO_SUSPEND_DETAILS        509
#define CHAN_INFO_SUSPEND_REASON         510
#define CHAN_INFO_SHOW_ALL               511
#define CHAN_LIST_SYNTAX                 512
#define CHAN_LIST_OPER_SYNTAX            513
#define CHAN_LIST_HEADER                 514
#define CHAN_LIST_END                    515
#define CHAN_INVITE_SYNTAX               516
#define CHAN_INVITE_OK                   517
#define CHAN_OPVOICE_SYNTAX              518
#define CHAN_OP_SUCCEEDED                519
#define CHAN_OP_ALREADY                  520
#define CHAN_OP_FAILED                   521
#define CHAN_DEOP_SUCCEEDED              522
#define CHAN_DEOP_ALREADY                523
#define CHAN_DEOP_FAILED                 524
#define CHAN_VOICE_SUCCEEDED             525
#define CHAN_VOICE_ALREADY               526
#define CHAN_VOICE_FAILED                527
#define CHAN_DEVOICE_SUCCEEDED           528
#define CHAN_DEVOICE_ALREADY             529
#define CHAN_DEVOICE_FAILED              530
#define CHAN_HALFOP_SUCCEEDED            531
#define CHAN_HALFOP_ALREADY              532
#define CHAN_HALFOP_FAILED               533
#define CHAN_DEHALFOP_SUCCEEDED          534
#define CHAN_DEHALFOP_ALREADY            535
#define CHAN_DEHALFOP_FAILED             536
#define CHAN_PROTECT_SUCCEEDED           537
#define CHAN_PROTECT_ALREADY             538
#define CHAN_PROTECT_FAILED              539
#define CHAN_DEPROTECT_SUCCEEDED         540
#define CHAN_DEPROTECT_ALREADY           541
#define CHAN_DEPROTECT_FAILED            542
#define CHAN_UNBAN_SYNTAX                543
#define CHAN_UNBANNED                    544
#define CHAN_KICK_SYNTAX                 545
#define CHAN_KICK_PROTECTED              546
#define CHAN_KICKED                      547
#define CHAN_TOPIC_SYNTAX                548
#define CHAN_CLEAR_SYNTAX                549
#define CHAN_CLEARED_BANS                550
#define CHAN_CLEARED_EXCEPTIONS          551
#define CHAN_CLEARED_INVITES             552
#define CHAN_CLEARED_MODES               553
#define CHAN_CLEARED_OPS                 554
#define CHAN_CLEARED_HALFOPS             555
#define CHAN_CLEARED_VOICES              556
#define CHAN_CLEARED_USERS               557
#define CHAN_GETPASS_SYNTAX              558
#define CHAN_GETPASS_UNAVAILABLE         559
#define CHAN_GETPASS_PASSWORD_IS         560
#define CHAN_FORBID_SYNTAX               561
#define CHAN_FORBID_SHORT_CHANNEL        562
#define CHAN_FORBID_SUCCEEDED            563
#define CHAN_FORBID_FAILED               564
#define CHAN_SUSPEND_SYNTAX              565
#define CHAN_SUSPEND_SUCCEEDED           566
#define CHAN_SUSPEND_ALREADY_SUSPENDED   567
#define CHAN_UNSUSPEND_SYNTAX            568
#define CHAN_UNSUSPEND_SUCCEEDED         569
#define CHAN_UNSUSPEND_NOT_SUSPENDED     570
#define CHAN_SENDPASS_MAIL_SUBJECT       571
#define CHAN_SENDPASS_MAIL_BODY          572
#define CHAN_SENDPASS_SYNTAX             573
#define CHAN_SENDPASS_FAILED             574
#define CHAN_SENDPASS_FOUNDER_ONLY       575
#define CHAN_SENDPASS_NO_EMAIL           576
#define CHAN_SENDPASS_TOO_SOON           577
#define CHAN_SENDPASS_SENT               578
#define MEMO_HAVE_NEW_MEMO               579
#define MEMO_HAVE_NEW_MEMOS              580
#define MEMO_TYPE_READ_LAST              581
#define MEMO_TYPE_READ_NUM               582
#define MEMO_TYPE_LIST_NEW               583
#define MEMO_AT_LIMIT                    584
#define MEMO_OVER_LIMIT                  585
#define MEMO_NEW_MEMO_ARRIVED            586
#define MEMO_HAVE_NO_MEMOS               587
#define MEMO_X_HAS_NO_MEMOS              588
#define MEMO_DOES_NOT_EXIST              589
#define MEMO_LIST_NOT_FOUND              590
#define MEMO_SEND_SYNTAX                 591
#define MEMO_SEND_DISABLED               592
#define MEMO_SEND_PLEASE_WAIT            593
#define MEMO_X_GETS_NO_MEMOS             594
#define MEMO_X_HAS_TOO_MANY_MEMOS        595
#define MEMO_SENT                        596
#define MEMO_LIST_SYNTAX                 597
#define MEMO_HAVE_NO_NEW_MEMOS           598
#define MEMO_X_HAS_NO_NEW_MEMOS          599
#define MEMO_LIST_MEMOS                  600
#define MEMO_LIST_NEW_MEMOS              601
#define MEMO_LIST_CHAN_MEMOS             602
#define MEMO_LIST_CHAN_NEW_MEMOS         603
#define MEMO_LIST_HEADER                 604
#define MEMO_LIST_FORMAT                 605
#define MEMO_READ_SYNTAX                 606
#define MEMO_HEADER                      607
#define MEMO_CHAN_HEADER                 608
#define MEMO_SAVE_SYNTAX                 609
#define MEMO_SAVED_ONE                   610
#define MEMO_SAVED_SEVERAL               611
#define MEMO_DEL_SYNTAX                  612
#define MEMO_DELETED_NONE                613
#define MEMO_DELETED_ONE                 614
#define MEMO_DELETED_SEVERAL             615
#define MEMO_DELETED_ALL                 616
#define MEMO_SET_SYNTAX                  617
#define MEMO_SET_DISABLED                618
#define MEMO_SET_UNKNOWN_OPTION          619
#define MEMO_SET_NOTIFY_SYNTAX           620
#define MEMO_SET_NOTIFY_ON               621
#define MEMO_SET_NOTIFY_LOGON            622
#define MEMO_SET_NOTIFY_NEW              623
#define MEMO_SET_NOTIFY_OFF              624
#define MEMO_SET_LIMIT_SYNTAX            625
#define MEMO_SET_LIMIT_OPER_SYNTAX       626
#define MEMO_SET_YOUR_LIMIT_FORBIDDEN    627
#define MEMO_SET_LIMIT_FORBIDDEN         628
#define MEMO_SET_YOUR_LIMIT_TOO_HIGH     629
#define MEMO_SET_LIMIT_TOO_HIGH          630
#define MEMO_SET_LIMIT_OVERFLOW          631
#define MEMO_SET_YOUR_LIMIT              632
#define MEMO_SET_YOUR_LIMIT_ZERO         633
#define MEMO_SET_YOUR_LIMIT_DEFAULT      634
#define MEMO_UNSET_YOUR_LIMIT            635
#define MEMO_SET_LIMIT                   636
#define MEMO_SET_LIMIT_ZERO              637
#define MEMO_SET_LIMIT_DEFAULT           638
#define MEMO_UNSET_LIMIT                 639
#define MEMO_INFO_NO_MEMOS               640
#define MEMO_INFO_MEMO                   641
#define MEMO_INFO_MEMO_UNREAD            642
#define MEMO_INFO_MEMOS                  643
#define MEMO_INFO_MEMOS_ONE_UNREAD       644
#define MEMO_INFO_MEMOS_SOME_UNREAD      645
#define MEMO_INFO_MEMOS_ALL_UNREAD       646
#define MEMO_INFO_LIMIT                  647
#define MEMO_INFO_HARD_LIMIT             648
#define MEMO_INFO_LIMIT_ZERO             649
#define MEMO_INFO_HARD_LIMIT_ZERO        650
#define MEMO_INFO_NO_LIMIT               651
#define MEMO_INFO_NOTIFY_OFF             652
#define MEMO_INFO_NOTIFY_ON              653
#define MEMO_INFO_NOTIFY_RECEIVE         654
#define MEMO_INFO_NOTIFY_SIGNON          655
#define MEMO_INFO_X_NO_MEMOS             656
#define MEMO_INFO_X_MEMO                 657
#define MEMO_INFO_X_MEMO_UNREAD          658
#define MEMO_INFO_X_MEMOS                659
#define MEMO_INFO_X_MEMOS_ONE_UNREAD     660
#define MEMO_INFO_X_MEMOS_SOME_UNREAD    661
#define MEMO_INFO_X_MEMOS_ALL_UNREAD     662
#define MEMO_INFO_X_LIMIT                663
#define MEMO_INFO_X_HARD_LIMIT           664
#define MEMO_INFO_X_NO_LIMIT             665
#define MEMO_INFO_X_NOTIFY_OFF           666
#define MEMO_INFO_X_NOTIFY_ON            667
#define MEMO_INFO_X_NOTIFY_RECEIVE       668
#define MEMO_INFO_X_NOTIFY_SIGNON        669
#define MEMO_FORWARD_MAIL_SUBJECT        670
#define MEMO_FORWARD_MAIL_BODY           671
#define MEMO_FORWARD_SYNTAX              672
#define MEMO_FORWARD_NEED_EMAIL          673
#define MEMO_FORWARD_PLEASE_WAIT         674
#define MEMO_FORWARD_FAILED              675
#define MEMO_FORWARDED_NONE              676
#define MEMO_FORWARDED_ONE               677
#define MEMO_FORWARDED_SEVERAL           678
#define MEMO_FORWARDED_ALL               679
#define MEMO_FORWARDED_ALSO_TEMPFAIL     680
#define MEMO_FORWARDED_ALSO_PERMFAIL     681
#define MEMO_SET_FORWARD_SYNTAX          682
#define MEMO_SET_FORWARD_ON              683
#define MEMO_SET_FORWARD_COPY            684
#define MEMO_SET_FORWARD_OFF             685
#define MEMO_IGNORE_SYNTAX               686
#define MEMO_IGNORE_ADD_SYNTAX           687
#define MEMO_IGNORE_DEL_SYNTAX           688
#define MEMO_IGNORE_LIST_FULL            689
#define MEMO_IGNORE_ALREADY_PRESENT      690
#define MEMO_IGNORE_ADDED                691
#define MEMO_IGNORE_NOT_FOUND            692
#define MEMO_IGNORE_DELETED              693
#define MEMO_IGNORE_LIST_EMPTY           694
#define MEMO_IGNORE_LIST                 695
#define MEMO_IGNORE_LIST_X_EMPTY         696
#define MEMO_IGNORE_LIST_X               697
#define OPER_BOUNCY_MODES                698
#define OPER_BOUNCY_MODES_U_LINE         699
#define OPER_GLOBAL_SYNTAX               700
#define OPER_STATS_UNKNOWN_OPTION        701
#define OPER_STATS_RESET_USER_COUNT      702
#define OPER_STATS_CURRENT_USERS         703
#define OPER_STATS_MAX_USERS             704
#define OPER_STATS_UPTIME_DHMS           705
#define OPER_STATS_UPTIME_HM_MS          706
#define OPER_STATS_KBYTES_READ           707
#define OPER_STATS_KBYTES_WRITTEN        708
#define OPER_STATS_NETBUF_SOCK           709
#define OPER_STATS_NETBUF_SOCK_PERCENT   710
#define OPER_STATS_NETBUF_TOTAL          711
#define OPER_STATS_NETBUF_TOTAL_PERCENT  712
#define OPER_STATS_ALL_USER_MEM          713
#define OPER_STATS_ALL_CHANNEL_MEM       714
#define OPER_STATS_ALL_SERVER_MEM        715
#define OPER_STATS_ALL_NICKGROUPINFO_MEM 716
#define OPER_STATS_ALL_NICKINFO_MEM      717
#define OPER_STATS_ALL_CHANSERV_MEM      718
#define OPER_STATS_ALL_STATSERV_MEM      719
#define OPER_STATS_ALL_NEWS_MEM          720
#define OPER_STATS_ALL_AKILL_MEM         721
#define OPER_STATS_ALL_EXCEPTION_MEM     722
#define OPER_STATS_ALL_SGLINE_MEM        723
#define OPER_STATS_ALL_SQLINE_MEM        724
#define OPER_STATS_ALL_SZLINE_MEM        725
#define OPER_STATS_ALL_SESSION_MEM       726
#define OPER_MODE_SYNTAX                 727
#define OPER_CLEARMODES_SYNTAX           728
#define OPER_CLEARMODES_DONE             729
#define OPER_CLEARMODES_EXCEPT_DONE      730
#define OPER_CLEARMODES_ALL_DONE         731
#define OPER_CLEARCHAN_SYNTAX            732
#define OPER_CLEARCHAN_DONE              733
#define OPER_KICK_SYNTAX                 734
#define OPER_ADMIN_SYNTAX                735
#define OPER_ADMIN_ADD_SYNTAX            736
#define OPER_ADMIN_DEL_SYNTAX            737
#define OPER_ADMIN_NO_NICKSERV           738
#define OPER_ADMIN_EXISTS                739
#define OPER_ADMIN_ADDED                 740
#define OPER_ADMIN_TOO_MANY              741
#define OPER_ADMIN_REMOVED               742
#define OPER_ADMIN_NOT_FOUND             743
#define OPER_ADMIN_LIST_HEADER           744
#define OPER_OPER_SYNTAX                 745
#define OPER_OPER_ADD_SYNTAX             746
#define OPER_OPER_DEL_SYNTAX             747
#define OPER_OPER_NO_NICKSERV            748
#define OPER_OPER_EXISTS                 749
#define OPER_OPER_ADDED                  750
#define OPER_OPER_TOO_MANY               751
#define OPER_OPER_REMOVED                752
#define OPER_OPER_NOT_FOUND              753
#define OPER_OPER_LIST_HEADER            754
#define OPER_AKILL_SYNTAX                755
#define OPER_AKILL_ADD_SYNTAX            756
#define OPER_AKILL_DEL_SYNTAX            757
#define OPER_TOO_MANY_AKILLS             758
#define OPER_AKILL_EXISTS                759
#define OPER_AKILL_NO_NICK               760
#define OPER_AKILL_MASK_TOO_GENERAL      761
#define OPER_AKILL_EXPIRY_LIMITED        762
#define OPER_AKILL_ADDED                 763
#define OPER_AKILL_REMOVED               764
#define OPER_AKILL_NOT_FOUND             765
#define OPER_AKILL_LIST_HEADER           766
#define OPER_AKILL_LIST_FORMAT           767
#define OPER_AKILL_VIEW_FORMAT           768
#define OPER_AKILL_VIEW_UNUSED_FORMAT    769
#define OPER_AKILL_COUNT                 770
#define OPER_AKILLCHAN_SYNTAX            771
#define OPER_AKILLCHAN_AKILLED           772
#define OPER_AKILLCHAN_KILLED            773
#define OPER_AKILLCHAN_AKILLED_ONE       774
#define OPER_AKILLCHAN_KILLED_ONE        775
#define OPER_EXCLUDE_SYNTAX              776
#define OPER_EXCLUDE_ADD_SYNTAX          777
#define OPER_EXCLUDE_DEL_SYNTAX          778
#define OPER_TOO_MANY_EXCLUDES           779
#define OPER_EXCLUDE_EXISTS              780
#define OPER_EXCLUDE_ADDED               781
#define OPER_EXCLUDE_REMOVED             782
#define OPER_EXCLUDE_NOT_FOUND           783
#define OPER_EXCLUDE_LIST_HEADER         784
#define OPER_EXCLUDE_LIST_FORMAT         785
#define OPER_EXCLUDE_VIEW_FORMAT         786
#define OPER_EXCLUDE_VIEW_UNUSED_FORMAT  787
#define OPER_EXCLUDE_COUNT               788
#define OPER_SLINE_SYNTAX                789
#define OPER_SLINE_ADD_SYNTAX            790
#define OPER_SLINE_DEL_SYNTAX            791
#define OPER_TOO_MANY_SLINES             792
#define OPER_SLINE_EXISTS                793
#define OPER_SLINE_ADDED                 794
#define OPER_SLINE_REMOVED               795
#define OPER_SLINE_NOT_FOUND             796
#define OPER_SLINE_LIST_HEADER           797
#define OPER_SLINE_LIST_FORMAT           798
#define OPER_SLINE_VIEW_FORMAT           799
#define OPER_SLINE_VIEW_UNUSED_FORMAT    800
#define OPER_SLINE_COUNT                 801
#define OPER_SZLINE_NOT_AVAIL            802
#define OPER_SU_SYNTAX                   803
#define OPER_SU_NO_PASSWORD              804
#define OPER_SU_SUCCEEDED                805
#define OPER_SU_FAILED                   806
#define OPER_SET_SYNTAX                  807
#define OPER_SET_IGNORE_ON               808
#define OPER_SET_IGNORE_OFF              809
#define OPER_SET_IGNORE_ERROR            810
#define OPER_SET_READONLY_ON             811
#define OPER_SET_READONLY_OFF            812
#define OPER_SET_READONLY_ERROR          813
#define OPER_SET_DEBUG_ON                814
#define OPER_SET_DEBUG_OFF               815
#define OPER_SET_DEBUG_LEVEL             816
#define OPER_SET_DEBUG_ERROR             817
#define OPER_SET_SUPASS_FAILED           818
#define OPER_SET_SUPASS_OK               819
#define OPER_SET_SUPASS_NONE             820
#define OPER_SET_UNKNOWN_OPTION          821
#define OPER_JUPE_SYNTAX                 822
#define OPER_JUPE_INVALID_NAME           823
#define OPER_JUPE_ALREADY_JUPED          824
#define OPER_RAW_SYNTAX                  825
#define OPER_UPDATE_SYNTAX               826
#define OPER_UPDATE_FORCE_FAILED         827
#define OPER_UPDATING                    828
#define OPER_UPDATE_COMPLETE             829
#define OPER_UPDATE_FAILED               830
#define OPER_REHASHING                   831
#define OPER_REHASHED                    832
#define OPER_REHASH_ERROR                833
#define OPER_IGNORE_LIST                 834
#define OPER_IGNORE_LIST_EMPTY           835
#define OPER_KILLCLONES_SYNTAX           836
#define OPER_KILLCLONES_UNKNOWN_NICK     837
#define OPER_KILLCLONES_KILLED           838
#define OPER_KILLCLONES_KILLED_AKILL     839
#define OPER_EXCEPTION_SYNTAX            840
#define OPER_EXCEPTION_ADD_SYNTAX        841
#define OPER_EXCEPTION_DEL_SYNTAX        842
#define OPER_EXCEPTION_MOVE_SYNTAX       843
#define OPER_EXCEPTION_ALREADY_PRESENT   844
#define OPER_EXCEPTION_TOO_MANY          845
#define OPER_EXCEPTION_ADDED             846
#define OPER_EXCEPTION_MOVED             847
#define OPER_EXCEPTION_NO_SUCH_ENTRY     848
#define OPER_EXCEPTION_NOT_FOUND         849
#define OPER_EXCEPTION_NO_MATCH          850
#define OPER_EXCEPTION_EMPTY             851
#define OPER_EXCEPTION_DELETED           852
#define OPER_EXCEPTION_DELETED_ONE       853
#define OPER_EXCEPTION_DELETED_SEVERAL   854
#define OPER_EXCEPTION_LIST_HEADER       855
#define OPER_EXCEPTION_LIST_COLHEAD      856
#define OPER_EXCEPTION_LIST_FORMAT       857
#define OPER_EXCEPTION_VIEW_FORMAT       858
#define OPER_EXCEPTION_INVALID_LIMIT     859
#define OPER_EXCEPTION_INVALID_HOSTMASK  860
#define OPER_SESSION_SYNTAX              861
#define OPER_SESSION_LIST_SYNTAX         862
#define OPER_SESSION_VIEW_SYNTAX         863
#define OPER_SESSION_INVALID_THRESHOLD   864
#define OPER_SESSION_NOT_FOUND           865
#define OPER_SESSION_LIST_HEADER         866
#define OPER_SESSION_LIST_COLHEAD        867
#define OPER_SESSION_LIST_FORMAT         868
#define OPER_SESSION_VIEW_FORMAT         869
#define NEWS_LOGON_TEXT                  870
#define NEWS_OPER_TEXT                   871
#define NEWS_LOGON_SYNTAX                872
#define NEWS_LOGON_LIST_HEADER           873
#define NEWS_LOGON_LIST_ENTRY            874
#define NEWS_LOGON_LIST_NONE             875
#define NEWS_LOGON_ADD_SYNTAX            876
#define NEWS_LOGON_ADD_FULL              877
#define NEWS_LOGON_ADDED                 878
#define NEWS_LOGON_DEL_SYNTAX            879
#define NEWS_LOGON_DEL_NOT_FOUND         880
#define NEWS_LOGON_DELETED               881
#define NEWS_LOGON_DEL_NONE              882
#define NEWS_LOGON_DELETED_ALL           883
#define NEWS_OPER_SYNTAX                 884
#define NEWS_OPER_LIST_HEADER            885
#define NEWS_OPER_LIST_ENTRY             886
#define NEWS_OPER_LIST_NONE              887
#define NEWS_OPER_ADD_SYNTAX             888
#define NEWS_OPER_ADD_FULL               889
#define NEWS_OPER_ADDED                  890
#define NEWS_OPER_DEL_SYNTAX             891
#define NEWS_OPER_DEL_NOT_FOUND          892
#define NEWS_OPER_DELETED                893
#define NEWS_OPER_DEL_NONE               894
#define NEWS_OPER_DELETED_ALL            895
#define NEWS_HELP_LOGON                  896
#define NEWS_HELP_OPER                   897
#define STAT_SERVERS_REMOVE_SERV_FIRST   898
#define STAT_SERVERS_SERVER_EXISTS       899
#define STAT_SERVERS_SYNTAX              900
#define STAT_SERVERS_STATS_TOTAL         901
#define STAT_SERVERS_STATS_ON_OFFLINE    902
#define STAT_SERVERS_LASTQUIT_WAS        903
#define STAT_SERVERS_LIST_HEADER         904
#define STAT_SERVERS_LIST_FORMAT         905
#define STAT_SERVERS_LIST_RESULTS        906
#define STAT_SERVERS_VIEW_HEADER_ONLINE  907
#define STAT_SERVERS_VIEW_HEADER_OFFLINE 908
#define STAT_SERVERS_VIEW_LASTJOIN       909
#define STAT_SERVERS_VIEW_LASTQUIT       910
#define STAT_SERVERS_VIEW_QUITMSG        911
#define STAT_SERVERS_VIEW_USERS_OPERS    912
#define STAT_SERVERS_VIEW_RESULTS        913
#define STAT_SERVERS_DELETE_SYNTAX       914
#define STAT_SERVERS_DELETE_DONE         915
#define STAT_SERVERS_COPY_SYNTAX         916
#define STAT_SERVERS_COPY_DONE           917
#define STAT_SERVERS_RENAME_SYNTAX       918
#define STAT_SERVERS_RENAME_DONE         919
#define STAT_USERS_SYNTAX                920
#define STAT_USERS_TOTUSERS              921
#define STAT_USERS_TOTOPERS              922
#define STAT_USERS_SERVUSERS             923
#define STAT_USERS_SERVOPERS             924
#define NICK_HELP                        925
#define NICK_HELP_EXPIRES                926
#define NICK_HELP_WARNING                927
#define NICK_HELP_COMMANDS               928
#define NICK_HELP_COMMANDS_AUTH          929
#define NICK_HELP_COMMANDS_IDENTIFY      930
#define NICK_HELP_COMMANDS_SENDPASS      931
#define NICK_HELP_COMMANDS_DROP          932
#define NICK_HELP_COMMANDS_LINK          933
#define NICK_HELP_COMMANDS_OLDLINK       934
#define NICK_HELP_COMMANDS_ACCESS        935
#define NICK_HELP_COMMANDS_AJOIN         936
#define NICK_HELP_COMMANDS_SET           937
#define NICK_HELP_COMMANDS_LIST          938
#define NICK_HELP_COMMANDS_LISTCHANS     939
#define NICK_HELP_REGISTER               940
#define NICK_HELP_REGISTER_EMAIL         941
#define NICK_HELP_REGISTER_EMAIL_REQ     942
#define NICK_HELP_REGISTER_EMAIL_AUTH    943
#define NICK_HELP_REGISTER_END           944
#define NICK_HELP_AUTH                   945
#define NICK_HELP_SENDAUTH               946
#define NICK_HELP_SENDPASS               947
#define NICK_HELP_IDENTIFY               948
#define NICK_HELP_DROP                   949
#define NICK_HELP_DROP_LINK              950
#define NICK_HELP_DROP_END               951
#define NICK_HELP_OLD_LINK               952
#define NICK_HELP_LINK                   953
#define NICK_HELP_OLD_UNLINK             954
#define NICK_HELP_UNLINK                 955
#define NICK_HELP_LISTLINKS              956
#define NICK_HELP_ACCESS                 957
#define NICK_HELP_SET                    958
#define NICK_HELP_SET_OPTION_MAINNICK    959
#define NICK_HELP_SET_END                960
#define NICK_HELP_SET_PASSWORD           961
#define NICK_HELP_SET_LANGUAGE           962
#define NICK_HELP_SET_URL                963
#define NICK_HELP_SET_EMAIL              964
#define NICK_HELP_SET_INFO               965
#define NICK_HELP_SET_KILL               966
#define NICK_HELP_SET_SECURE             967
#define NICK_HELP_SET_PRIVATE            968
#define NICK_HELP_SET_HIDE               969
#define NICK_HELP_SET_TIMEZONE           970
#define NICK_HELP_SET_MAINNICK           971
#define NICK_HELP_UNSET                  972
#define NICK_HELP_UNSET_REQ_EMAIL        973
#define NICK_HELP_RECOVER                974
#define NICK_HELP_RELEASE                975
#define NICK_HELP_GHOST                  976
#define NICK_HELP_INFO                   977
#define NICK_HELP_INFO_AUTH              978
#define NICK_HELP_LISTCHANS              979
#define NICK_HELP_LIST                   980
#define NICK_HELP_LIST_OPERSONLY         981
#define NICK_HELP_LISTEMAIL              982
#define NICK_HELP_STATUS                 983
#define NICK_HELP_AJOIN                  984
#define NICK_HELP_AJOIN_END              985
#define NICK_HELP_AJOIN_END_CHANSERV     986
#define NICK_OPER_HELP_COMMANDS          987
#define NICK_OPER_HELP_COMMANDS_DROPEMAIL 988
#define NICK_OPER_HELP_COMMANDS_GETPASS  989
#define NICK_OPER_HELP_COMMANDS_FORBID   990
#define NICK_OPER_HELP_COMMANDS_LISTLINKS 991
#define NICK_OPER_HELP_COMMANDS_SETAUTH  992
#define NICK_OPER_HELP_COMMANDS_END      993
#define NICK_OPER_HELP_DROPNICK          994
#define NICK_OPER_HELP_DROPEMAIL         995
#define NICK_OPER_HELP_SET               996
#define NICK_OPER_HELP_SET_NOEXPIRE      997
#define NICK_OPER_HELP_UNSET             998
#define NICK_OPER_HELP_OLD_UNLINK        999
#define NICK_OPER_HELP_UNLINK            1000
#define NICK_OPER_HELP_OLD_LISTLINKS     1001
#define NICK_OPER_HELP_LISTLINKS         1002
#define NICK_OPER_HELP_ACCESS            1003
#define NICK_OPER_HELP_INFO              1004
#define NICK_OPER_HELP_LISTCHANS         1005
#define NICK_OPER_HELP_LIST              1006
#define NICK_OPER_HELP_LIST_AUTH         1007
#define NICK_OPER_HELP_LISTEMAIL         1008
#define NICK_OPER_HELP_LISTEMAIL_AUTH    1009
#define NICK_OPER_HELP_GETPASS           1010
#define NICK_OPER_HELP_FORBID            1011
#define NICK_OPER_HELP_SUSPEND           1012
#define NICK_OPER_HELP_UNSUSPEND         1013
#define NICK_OPER_HELP_AJOIN             1014
#define NICK_OPER_HELP_SETAUTH           1015
#define NICK_OPER_HELP_GETAUTH           1016
#define NICK_OPER_HELP_CLEARAUTH         1017
#define CHAN_HELP_REQSOP_LEVXOP          1018
#define CHAN_HELP_REQSOP_LEV             1019
#define CHAN_HELP_REQSOP_XOP             1020
#define CHAN_HELP_REQAOP_LEVXOP          1021
#define CHAN_HELP_REQAOP_LEV             1022
#define CHAN_HELP_REQAOP_XOP             1023
#define CHAN_HELP_REQHOP_LEVXOP          1024
#define CHAN_HELP_REQHOP_LEV             1025
#define CHAN_HELP_REQHOP_XOP             1026
#define CHAN_HELP_REQVOP_LEVXOP          1027
#define CHAN_HELP_REQVOP_LEV             1028
#define CHAN_HELP_REQVOP_XOP             1029
#define CHAN_HELP                        1030
#define CHAN_HELP_EXPIRES                1031
#define CHAN_HELP_COMMANDS               1032
#define CHAN_HELP_COMMANDS_SENDPASS      1033
#define CHAN_HELP_COMMANDS_DROP          1034
#define CHAN_HELP_COMMANDS_LIST          1035
#define CHAN_HELP_COMMANDS_AKICK         1036
#define CHAN_HELP_COMMANDS_LEVELS        1037
#define CHAN_HELP_COMMANDS_XOP           1038
#define CHAN_HELP_COMMANDS_HOP           1039
#define CHAN_HELP_COMMANDS_OPVOICE       1040
#define CHAN_HELP_COMMANDS_HALFOP        1041
#define CHAN_HELP_COMMANDS_PROTECT       1042
#define CHAN_HELP_COMMANDS_INVITE        1043
#define CHAN_HELP_REGISTER               1044
#define CHAN_HELP_REGISTER_ADMINONLY     1045
#define CHAN_HELP_SENDPASS               1046
#define CHAN_HELP_IDENTIFY               1047
#define CHAN_HELP_DROP                   1048
#define CHAN_HELP_SET                    1049
#define CHAN_HELP_SET_FOUNDER            1050
#define CHAN_HELP_SET_SUCCESSOR          1051
#define CHAN_HELP_SET_PASSWORD           1052
#define CHAN_HELP_SET_DESC               1053
#define CHAN_HELP_SET_URL                1054
#define CHAN_HELP_SET_EMAIL              1055
#define CHAN_HELP_SET_ENTRYMSG           1056
#define CHAN_HELP_SET_KEEPTOPIC          1057
#define CHAN_HELP_SET_TOPICLOCK          1058
#define CHAN_HELP_SET_MLOCK              1059
#define CHAN_HELP_SET_HIDE               1060
#define CHAN_HELP_SET_PRIVATE            1061
#define CHAN_HELP_SET_RESTRICTED         1062
#define CHAN_HELP_SET_SECURE             1063
#define CHAN_HELP_SET_SECUREOPS          1064
#define CHAN_HELP_SET_LEAVEOPS           1065
#define CHAN_HELP_SET_OPNOTICE           1066
#define CHAN_HELP_SET_ENFORCE            1067
#define CHAN_HELP_UNSET                  1068
#define CHAN_HELP_SOP                    1069
#define CHAN_HELP_SOP_MID1               1070
#define CHAN_HELP_SOP_MID1_CHANPROT      1071
#define CHAN_HELP_SOP_MID2               1072
#define CHAN_HELP_SOP_MID2_HALFOP        1073
#define CHAN_HELP_SOP_END                1074
#define CHAN_HELP_AOP                    1075
#define CHAN_HELP_AOP_MID                1076
#define CHAN_HELP_AOP_MID_HALFOP         1077
#define CHAN_HELP_AOP_END                1078
#define CHAN_HELP_HOP                    1079
#define CHAN_HELP_VOP                    1080
#define CHAN_HELP_ACCESS                 1081
#define CHAN_HELP_ACCESS_XOP             1082
#define CHAN_HELP_ACCESS_XOP_HALFOP      1083
#define CHAN_HELP_ACCESS_LEVELS          1084
#define CHAN_HELP_ACCESS_LEVELS_HALFOP   1085
#define CHAN_HELP_ACCESS_LEVELS_END      1086
#define CHAN_HELP_LEVELS                 1087
#define CHAN_HELP_LEVELS_XOP             1088
#define CHAN_HELP_LEVELS_XOP_HOP         1089
#define CHAN_HELP_LEVELS_END             1090
#define CHAN_HELP_LEVELS_DESC            1091
#define CHAN_HELP_AKICK                  1092
#define CHAN_HELP_INFO                   1093
#define CHAN_HELP_LIST                   1094
#define CHAN_HELP_LIST_OPERSONLY         1095
#define CHAN_HELP_OP                     1096
#define CHAN_HELP_DEOP                   1097
#define CHAN_HELP_VOICE                  1098
#define CHAN_HELP_DEVOICE                1099
#define CHAN_HELP_HALFOP                 1100
#define CHAN_HELP_DEHALFOP               1101
#define CHAN_HELP_PROTECT                1102
#define CHAN_HELP_DEPROTECT              1103
#define CHAN_HELP_INVITE                 1104
#define CHAN_HELP_UNBAN                  1105
#define CHAN_HELP_KICK                   1106
#define CHAN_HELP_KICK_PROTECTED         1107
#define CHAN_HELP_TOPIC                  1108
#define CHAN_HELP_CLEAR                  1109
#define CHAN_HELP_CLEAR_EXCEPTIONS       1110
#define CHAN_HELP_CLEAR_INVITES          1111
#define CHAN_HELP_CLEAR_MID              1112
#define CHAN_HELP_CLEAR_HALFOPS          1113
#define CHAN_HELP_CLEAR_END              1114
#define CHAN_HELP_STATUS                 1115
#define CHAN_OPER_HELP_COMMANDS          1116
#define CHAN_OPER_HELP_COMMANDS_GETPASS  1117
#define CHAN_OPER_HELP_COMMANDS_FORBID   1118
#define CHAN_OPER_HELP_COMMANDS_END      1119
#define CHAN_OPER_HELP_DROP              1120
#define CHAN_OPER_HELP_SET               1121
#define CHAN_OPER_HELP_SET_NOEXPIRE      1122
#define CHAN_OPER_HELP_UNSET             1123
#define CHAN_OPER_HELP_INFO              1124
#define CHAN_OPER_HELP_LIST              1125
#define CHAN_OPER_HELP_GETPASS           1126
#define CHAN_OPER_HELP_FORBID            1127
#define CHAN_OPER_HELP_SUSPEND           1128
#define CHAN_OPER_HELP_UNSUSPEND         1129
#define MEMO_HELP                        1130
#define MEMO_HELP_EXPIRES                1131
#define MEMO_HELP_END_LEVELS             1132
#define MEMO_HELP_END_XOP                1133
#define MEMO_HELP_COMMANDS               1134
#define MEMO_HELP_COMMANDS_FORWARD       1135
#define MEMO_HELP_COMMANDS_SAVE          1136
#define MEMO_HELP_COMMANDS_DEL           1137
#define MEMO_HELP_COMMANDS_IGNORE        1138
#define MEMO_HELP_SEND                   1139
#define MEMO_HELP_LIST                   1140
#define MEMO_HELP_LIST_EXPIRE            1141
#define MEMO_HELP_READ                   1142
#define MEMO_HELP_SAVE                   1143
#define MEMO_HELP_DEL                    1144
#define MEMO_HELP_SET                    1145
#define MEMO_HELP_SET_OPTION_FORWARD     1146
#define MEMO_HELP_SET_END                1147
#define MEMO_HELP_SET_NOTIFY             1148
#define MEMO_HELP_SET_LIMIT              1149
#define MEMO_HELP_INFO                   1150
#define MEMO_OPER_HELP_COMMANDS          1151
#define MEMO_OPER_HELP_SET_LIMIT         1152
#define MEMO_OPER_HELP_INFO              1153
#define MEMO_HELP_FORWARD                1154
#define MEMO_HELP_SET_FORWARD            1155
#define MEMO_HELP_IGNORE                 1156
#define OPER_HELP                        1157
#define OPER_HELP_COMMANDS               1158
#define OPER_HELP_COMMANDS_SERVOPER      1159
#define OPER_HELP_COMMANDS_AKILL         1160
#define OPER_HELP_COMMANDS_EXCLUDE       1161
#define OPER_HELP_COMMANDS_SLINE         1162
#define OPER_HELP_COMMANDS_SESSION       1163
#define OPER_HELP_COMMANDS_NEWS          1164
#define OPER_HELP_COMMANDS_SERVADMIN     1165
#define OPER_HELP_COMMANDS_SERVROOT      1166
#define OPER_HELP_COMMANDS_RAW           1167
#define OPER_HELP_GLOBAL                 1168
#define OPER_HELP_STATS                  1169
#define OPER_HELP_SERVERMAP              1170
#define OPER_HELP_OPER                   1171
#define OPER_HELP_ADMIN                  1172
#define OPER_HELP_MODE                   1173
#define OPER_HELP_CLEARMODES             1174
#define OPER_HELP_CLEARCHAN              1175
#define OPER_HELP_KICK                   1176
#define OPER_HELP_AKILL                  1177
#define OPER_HELP_AKILL_OPERMAXEXPIRY    1178
#define OPER_HELP_AKILL_END              1179
#define OPER_HELP_AKILLCHAN              1180
#define OPER_HELP_EXCLUDE                1181
#define OPER_HELP_SGLINE                 1182
#define OPER_HELP_SQLINE                 1183
#define OPER_HELP_SQLINE_KILL            1184
#define OPER_HELP_SQLINE_NOKILL          1185
#define OPER_HELP_SQLINE_IGNOREOPERS     1186
#define OPER_HELP_SQLINE_END             1187
#define OPER_HELP_SZLINE                 1188
#define OPER_HELP_EXCEPTION              1189
#define OPER_HELP_SESSION                1190
#define OPER_HELP_SU                     1191
#define OPER_HELP_SET                    1192
#define OPER_HELP_SET_READONLY           1193
#define OPER_HELP_SET_DEBUG              1194
#define OPER_HELP_SET_SUPASS             1195
#define OPER_HELP_JUPE                   1196
#define OPER_HELP_RAW                    1197
#define OPER_HELP_UPDATE                 1198
#define OPER_HELP_QUIT                   1199
#define OPER_HELP_SHUTDOWN               1200
#define OPER_HELP_RESTART                1201
#define OPER_HELP_REHASH                 1202
#define OPER_HELP_KILLCLONES             1203
#define STAT_HELP                        1204
#define STAT_HELP_COMMANDS               1205
#define STAT_HELP_SERVERS                1206
#define STAT_HELP_USERS                  1207
#define STAT_OPER_HELP_SERVERS           1208

#define NUM_STRINGS 1209
